package com.godmonth.util;

import org.apache.commons.lang.UnhandledException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class EndlessTask implements Runnable {

	protected Logger logger = LoggerFactory.getLogger(getClass());
	private Runnable runnable;
	private int sleepTime;
	private boolean breakOnException;

	public EndlessTask(Runnable runnable, int sleepTime) {
		this(runnable, sleepTime, false);
	}

	public EndlessTask(Runnable runnable, int sleepTime,
			boolean breakOnException) {
		this.runnable = runnable;
		this.sleepTime = sleepTime;
		this.breakOnException = breakOnException;
	}

	public void run() {
		try {
			while (true) {
				try {
					runnable.run();
				} catch (Exception e) {
					if (breakOnException) {
						throw new UnhandledException(e);
					} else {
						logger.warn(null, e);
					}
				}

				if (Thread.currentThread().isInterrupted()) {
					logger.info("interrupted");
					break;
				}
				if (sleepTime > 0) {
					Thread.sleep(sleepTime);
				}

			}
		} catch (InterruptedException e) {
			logger.info(e.getMessage());
		}

	}
}
